scale_fill_tate_d: Discrete tate palettes for plotting with ggplot2

View source: R/scale_fill_tate_d.R

scale_fill_tate_dR Documentation

Discrete tate palettes for plotting with ggplot2

Description

A function to use colour palettes from tate with ggplot2. Use scale_colour_met_d and scale_fill_met_d for discrete scales, and scale_colour_met_c and scale_fill_met_c for continuous scales.

Usage

scale_fill_tate_d(name, direction = 1, ...)

Arguments

name

character. Name of desired palette. Either: Cholmondeley, Copley, Blake, Turner, Millais, Sargent, Waterhouse, Grant, Lowry, Bacon or Hockney.

direction

numeric. Sets the order of colours in the scale. Default order is 1. Palette is reversed by specifying -1.

...

Other arguments passed on to scale_colour_gradientn

Examples

# Load libraries
library(ggplot2)
library(palmerpenguins)
# Plot data
ggplot(data = penguins,
       aes(x = bill_length_mm, y = bill_depth_mm, fill = species)) +
  geom_point(colour = "black", pch = 21) +
  scale_fill_tate_d("Waterhouse", direction = 1)

LewisAJones/london documentation built on Aug. 31, 2022, 10:55 p.m.